package com.graywolf336.jail.beans;

import com.graywolf336.jail.enums.Confirmation;

/**
 * Holds data for when a player is confirming a command.
 *
 * @author graywolf336
 * @version 1.0.0
 * @since 3.0.0
 */
public class ConfirmPlayer {
    private final String name;
    private final String[] args;
    private final Confirmation confirm;
    private final Long expires;

    public ConfirmPlayer(String name, String[] args, Confirmation confirm) {
        this.name = name;
        this.args = args;
        this.confirm = confirm;
        this.expires = System.currentTimeMillis() + 10000L;
    }

    /**
     * Returns the name of the thing needing to confirm.
     *
     * @return the name of what is being confirmed
     */
    public String getName() {
        return this.name;
    }

    /**
     * Returns the initial arguments they sent with their command.
     *
     * @return the initial arguments of the original command
     */
    public String[] getArguments() {
        return this.args;
    }

    /**
     * Returns what they are {@link Confirmation confirming}.
     *
     * @return the {@link Confirmation} of what they're confirming
     */
    public Confirmation getConfirming() {
        return this.confirm;
    }

    /**
     * Returns the time in milliseconds their confirmation time frame expires.
     *
     * @return the time their confirming expires
     */
    public Long getExpiryTime() {
        return this.expires;
    }
}
