package com.graywolf336.jail.interfaces;

import com.graywolf336.jail.beans.Prisoner;
import net.milkbowl.vault.economy.Economy;
import org.bukkit.Material;
import org.bukkit.entity.Player;

public interface IJailPayManager {

    /**
     * Checks if paying for infinite is enabled.
     *
     * @return Whether infinite paying is enabled.
     */
    boolean isInfiniteEnabled();

    /**
     * Checks if paying for timed is enabled.
     *
     * @return Whether time paying is enabled.
     */
    boolean isTimedEnabled();

    /**
     * Gets how much it cost per minute in string format.
     *
     * @return How much it costs per minute
     */
    String getCostPerMinute();

    /**
     * Calculates how much players have to pay to get completely free.
     *
     * @param prisoner data of who we're calculating
     * @return The economy cost the prisoner will need to pay to get completely free.
     */
    double calculateBill(Prisoner prisoner);

    /**
     * Gets how many minutes someone is paying for (rounds to the lowest number).
     *
     * @param amount amount of money
     * @return the amount of time they're paying for
     */
    long getMinutesPayingFor(double amount);

    /**
     * Returns if we are using items for payment instead of economy.
     *
     * @return Whether paying using items is enabled
     */
    boolean usingItemsForPayment();

    /**
     * Gets the {@link Material} it costs for jail pay, will be air if using economy.
     *
     * @return The item type it costs, air if using virtual economy.
     */
    Material getItemItCost();

    /**
     * Checks if the player has enough money/items to pay what they have said they want to.
     *
     * @param player The player who is doing the paying.
     * @param amount The amount to check they if they have.
     * @return true if they have enough, false if not.
     */
    boolean hasEnoughToPay(Player player, double amount);

    /**
     * Pays the required fees from the given player, removing items or money from economy.
     *
     * @param player The player who is paying.
     * @param amount The amount of items or money to withdraw from the player.
     */
    void pay(Player player, double amount);

    /**
     * Gets the name of the item in nice capitals.
     *
     * @return The currency name in nice capital letters.
     */
    String getCurrencyName();

    /**
     * Returns the economy provider to do transaction with.
     *
     * @return the {@link Economy} instance
     */
    Economy getEconomy();
}
